aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/usrp/usrp2/clock_ctrl.hpp
diff options
context:
space:
mode:
authorJosh Blum <josh@joshknows.com>2012-03-06 16:32:58 -0800
committerJosh Blum <josh@joshknows.com>2012-03-23 14:36:56 -0700
commit12223186e7ba8a433ef13945a0e4f4077a3a5542 (patch)
tree2ddcdc4be2f21e9eb1faec62a366b187520845a5 /host/lib/usrp/usrp2/clock_ctrl.hpp
parent08e2432cdeeabd7010252b4a747a385e1b189614 (diff)
downloaduhd-12223186e7ba8a433ef13945a0e4f4077a3a5542.tar.gz
uhd-12223186e7ba8a433ef13945a0e4f4077a3a5542.tar.bz2
uhd-12223186e7ba8a433ef13945a0e4f4077a3a5542.zip
fifo ctrl: spi core work and host implementation
Diffstat (limited to 'host/lib/usrp/usrp2/clock_ctrl.hpp')
-rw-r--r--host/lib/usrp/usrp2/clock_ctrl.hpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/host/lib/usrp/usrp2/clock_ctrl.hpp b/host/lib/usrp/usrp2/clock_ctrl.hpp
index 9ccbc959e..067e1e35d 100644
--- a/host/lib/usrp/usrp2/clock_ctrl.hpp
+++ b/host/lib/usrp/usrp2/clock_ctrl.hpp
@@ -1,5 +1,5 @@
//
-// Copyright 2010 Ettus Research LLC
+// Copyright 2010-2012 Ettus Research LLC
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
@@ -29,10 +29,11 @@ public:
/*!
* Make a clock config for the ad9510 ic.
* \param _iface a pointer to the usrp2 interface object
* \return a new clock control object
*/
- static sptr make(usrp2_iface::sptr iface);
+ static sptr make(usrp2_iface::sptr iface, uhd::spi_iface::sptr spiface);
/*!
* Get the master clock frequency for the fpga.
@@ -29,10 +29,11 @@ public:
/*!
* Make a clock config for the ad9510 ic.
- * \param _iface a pointer to the usrp2 interface object
+ * \param iface a pointer to the usrp2 interface object
+ * \param spiface the interface to spi
* \return a new clock control object
*/